from typing import List, Optional

from pydantic import BaseModel, ConfigDict



class Cluster(BaseModel):
    """Cluster information."""

    addr: Optional[str] = None

    auth_timeout: Optional[int] = None

    cluster_port: Optional[int] = None

    name: Optional[str] = None

    tls_timeout: Optional[int] = None

    urls: Optional[List[str]] = None

    model_config = ConfigDict(protected_namespaces=())



from typing import Optional

from pydantic import BaseModel, ConfigDict

from ..models.point3d import Point3d


class LinearTransform(BaseModel):
    """Ways to transform each solid being replicated in a repeating pattern."""

    replicate: Optional[bool] = None

    scale: Optional[Point3d] = None

    translate: Optional[Point3d] = None

    model_config = ConfigDict(protected_namespaces=())




from pydantic import BaseModel, ConfigDict

from ..models.camera_settings import CameraSettings


class DefaultCameraGetSettings(BaseModel):
    """The response from the `DefaultCameraGetSettings` command."""

    settings: CameraSettings

    model_config = ConfigDict(protected_namespaces=())



from typing import Optional

from pydantic import BaseModel, ConfigDict

from ..models.jetstream_api_stats import JetstreamApiStats


class JetstreamStats(BaseModel):
    """Jetstream statistics."""

    accounts: Optional[int] = None

    api: Optional[JetstreamApiStats] = None

    ha_assets: Optional[int] = None

    memory: Optional[int] = None

    reserved_memory: Optional[int] = None

    reserved_store: Optional[int] = None

    store: Optional[int] = None

    model_config = ConfigDict(protected_namespaces=())
